@@ -42,6 +42,7 @@ module CharDet
       @highBitDetector = /[\x80-\xFF]/n
       @escDetector = /(\033|\~\{)/n
       @escCharSetProber = nil
+      @utf1632prober = nil
       @charSetProbers = []
       reset()
     end
@@ -56,6 +57,9 @@ module CharDet
       if @escCharSetProber
         @escCharSetProber.reset()
       end
+      if @utf1632prober
+        @utf1632prober.reset()
+      end
       for prober in @charSetProbers
         prober.reset()
       end
@@ -90,6 +94,16 @@ module CharDet
         elsif aBuf[0, 2] == "\xFE\xFF"
           # FE FF  UTF-16, big endian BOM
           @result = {'encoding' =>  "UTF-16BE", 'confidence' =>  1.0}
+        elsif aBuf[0, 3] == "\x2B\x2F\x76" && ["\x38", "\x39", "\x2B", "\x2F"].include?(aBuf[3, 1])
+          # NOTE: Ruby only includes "dummy" support for UTF-7.
+          # A Ruby UTF-7 string can't have methods called on it, nor can it be converted to anything else, but "BINARY"/"ASCII-8BIT".
+          # Still, this doesn't make detection useless, as UTF-7 encodings exist in the wild, and the scenario may need to be handled.
+          # 2B 2F 76 38  UTF-7
+          # 2B 2F 76 39  UTF-7
+          # 2B 2F 76 2B  UTF-7
+          # 2B 2F 76 2F  UTF-7
+          # 2B 2F 76 38 2D  UTF-7 with no following character (empty string)
+          @result = {'encoding' =>  "UTF-7", 'confidence' =>  0.99}
         end
       end
 
@@ -107,6 +121,22 @@ module CharDet
       end
 
       @lastChar = aBuf[-1, 1]
+
+      if !@utf1632prober
+        @utf1632prober = UTF1632Prober.new()
+      end
+
+      if @utf1632prober.get_state == EDetecting
+        if @utf1632prober.feed(aBuf) == EFoundIt
+          @result = {
+            "encoding" => @utf1632prober.get_charset_name(),
+            "confidence" => @utf1632prober.get_confidence()
+          }
+        @done = true
+        return
+        end
+      end
+
       if @inputState == EEscAscii
         if !@escCharSetProber
           @escCharSetProber = EscCharSetProber.new()
